pub struct FontTemplate {
pub identifier: FontIdentifier,
pub descriptor: FontTemplateDescriptor,
pub font_face_rule: Option<Descriptors>,
}Expand description
This describes all the information needed to create font instance handles. It contains a unique FontTemplateData structure that is platform specific.
Fields
identifier: FontIdentifierdescriptor: FontTemplateDescriptorfont_face_rule: Option<Descriptors>If this font is a web font, this is a reference to the @font-face rule that
created it.
Implementations
Sourceimpl FontTemplate
Holds all of the template information for a font that
is common, regardless of the number of instances of
this font handle per thread.
impl FontTemplate
Holds all of the template information for a font that is common, regardless of the number of instances of this font handle per thread.
Sourcepub fn new(
identifier: FontIdentifier,
descriptor: FontTemplateDescriptor,
font_face_rule: Option<FontFaceRuleDescriptors>,
) -> FontTemplate
pub fn new( identifier: FontIdentifier, descriptor: FontTemplateDescriptor, font_face_rule: Option<FontFaceRuleDescriptors>, ) -> FontTemplate
Create a new FontTemplate.
Sourcepub fn new_for_local_web_font(
local_template: FontTemplateRef,
css_font_template_descriptors: &CSSFontFaceDescriptors,
font_face_rule: Option<FontFaceRuleDescriptors>,
) -> Result<FontTemplate, &'static str>
pub fn new_for_local_web_font( local_template: FontTemplateRef, css_font_template_descriptors: &CSSFontFaceDescriptors, font_face_rule: Option<FontFaceRuleDescriptors>, ) -> Result<FontTemplate, &'static str>
Create a new FontTemplate for a @font-family with a local(...) src. This takes in
the template of the local font and creates a new one that reflects the properties specified
by @font-family in the stylesheet.
pub fn identifier(&self) -> &FontIdentifier
Sourcepub fn compute_variations(
&self,
descriptor: &FontDescriptor,
) -> Vec<FontVariation>
pub fn compute_variations( &self, descriptor: &FontDescriptor, ) -> Vec<FontVariation>
pub fn is_defined_by_font_face_rule( &self, rule: &FontFaceRuleDescriptors, ) -> bool